@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-gcal" "0.4.3"
+(define-package "org-gcal" "20260225.409"
   "Org sync with Google Calendar."
   '((aio              "1.0")
     (alert            "1.2")
@@ -10,8 +10,8 @@
     (request          "20190901")
     (request-deferred "20181129"))
   :url "https://github.com/kidd/org-gcal.el"
-  :commit "9627478a7d26468957d965ebb858e5ff9e260568"
-  :revdesc "v0.4.3-0-g9627478a7d26"
+  :commit "0f46c08f60355729526e970e370defe624e84956"
+  :revdesc "0f46c08f6035"
   :keywords '("convenience")
   :authors '(("myuhe" . "yuhei.maeda_at_gmail.com"))
   :maintainers '(("Raimon Grau" . "raimonster@gmail.com")))
