@@ -2,8 +2,8 @@
 
 ;; Author: myuhe <yuhei.maeda_at_gmail.com>
 ;; URL: https://github.com/kidd/org-gcal.el
-;; Package-Version: 0.4.3
-;; Package-Revision: v0.4.3-0-g9627478a7d26
+;; Package-Version: 20260225.409
+;; Package-Revision: 0f46c08f6035
 ;; Maintainer: Raimon Grau <raimonster@gmail.com>
 ;; Package-Requires: ((aio "1.0") (alert "1.2") (emacs "26.1") (oauth2-auto "20240326.2225") (org "9.3") (persist "0.8") (request "20190901") (request-deferred "20181129"))
 ;; Copyright (C) :2014 myuhe all rights reserved.
@@ -289,6 +289,11 @@ entries."
   :group 'org-gcal
   :type 'string)
 
+(defcustom org-gcal-event-default-duration 5
+  "Default duration of events in minutes."
+  :group 'org-gcal
+  :type 'integer)
+
 (defvar org-gcal--sync-lock nil
   "Set if a sync function is running.")
 
@@ -1289,12 +1294,11 @@ For valid values of EXISTING-MODE see
              (desc (plist-get time-desc :desc)))
         (unless end
           (let* ((start-time (or start (org-read-date 'with-time 'to-time)))
-                 (min-duration 5)
                  (resolution 5)
                  (duration-default
                   (org-duration-from-minutes
                    (max
-                    min-duration
+                    org-gcal-event-default-duration
                     ;; Round up to the nearest multiple of ‘resolution’ minutes.
                     (* resolution
                        (ceiling
